@@ -52,17 +52,17 @@ CurlRequest::CurlRequest(CurlGlobal &_global,
 {
 	error_buffer[0] = 0;
 
-	easy.SetOption(CURLOPT_PRIVATE, (void *)this);
-	easy.SetOption(CURLOPT_USERAGENT, "Music Player Daemon " VERSION);
-	easy.SetOption(CURLOPT_HEADERFUNCTION, _HeaderFunction);
-	easy.SetOption(CURLOPT_WRITEHEADER, this);
-	easy.SetOption(CURLOPT_WRITEFUNCTION, WriteFunction);
-	easy.SetOption(CURLOPT_WRITEDATA, this);
-	easy.SetOption(CURLOPT_NETRC, 1l);
-	easy.SetOption(CURLOPT_ERRORBUFFER, error_buffer);
-	easy.SetOption(CURLOPT_NOPROGRESS, 1l);
-	easy.SetOption(CURLOPT_NOSIGNAL, 1l);
-	easy.SetOption(CURLOPT_CONNECTTIMEOUT, 10l);
+	easy.SetPrivate((void *)this);
+	easy.SetUserAgent("Music Player Daemon " VERSION);
+	easy.SetHeaderFunction(_HeaderFunction, this);
+	easy.SetWriteFunction(WriteFunction, this);
+#ifndef ANDROID
+	easy.SetOption(CURLOPT_NETRC, 1L);
+#endif
+	easy.SetErrorBuffer(error_buffer);
+	easy.SetNoProgress();
+	easy.SetNoSignal();
+	easy.SetConnectTimeout(10);
 	easy.SetOption(CURLOPT_HTTPAUTH, (long) CURLAUTH_ANY);
 }
 
@@ -121,7 +121,7 @@ CurlRequest::Resume() noexcept
 {
 	assert(registered);
 
-	curl_easy_pause(easy.Get(), CURLPAUSE_CONT);
+	easy.Unpause();
 
 	global.InvalidateSockets();
 }
@@ -220,14 +220,14 @@ CurlRequest::HeaderFunction(StringView s) noexcept
 }
 
 size_t
-CurlRequest::_HeaderFunction(void *ptr, size_t size, size_t nmemb,
+CurlRequest::_HeaderFunction(char *ptr, size_t size, size_t nmemb,
 			     void *stream) noexcept
 {
 	CurlRequest &c = *(CurlRequest *)stream;
 
 	size *= nmemb;
 
-	c.HeaderFunction({(const char *)ptr, size});
+	c.HeaderFunction({ptr, size});
 	return size;
 }
 
@@ -254,7 +254,7 @@ CurlRequest::DataReceived(const void *ptr, size_t received_size) noexcept
 }
 
 size_t
-CurlRequest::WriteFunction(void *ptr, size_t size, size_t nmemb,
+CurlRequest::WriteFunction(char *ptr, size_t size, size_t nmemb,
 			   void *stream) noexcept
 {
 	CurlRequest &c = *(CurlRequest *)stream;
