@@ -22,6 +22,7 @@
 #include "../OutputAPI.hxx"
 #include "mixer/MixerList.hxx"
 #include "util/Domain.hxx"
+#include "util/Math.hxx"
 #include "system/Error.hxx"
 #include "Log.hxx"
 
@@ -37,8 +38,6 @@
 #include <StringList.h>
 #include <SoundPlayer.h>
 
-#include <cmath>
-
 #include <string.h>
 
 #define UTF8_PLAY "\xE2\x96\xB6"
