@@ -28,6 +28,7 @@
 #include "util/Macros.hxx"
 #include "util/Domain.hxx"
 #include "system/ByteOrder.hxx"
+#include "mixer/MixerList.hxx"
 #include "Log.hxx"
 
 #include <SLES/OpenSLES.h>
@@ -412,5 +413,5 @@ const struct AudioOutputPlugin sles_output_plugin = {
 	"sles",
 	sles_test_default_device,
 	SlesOutput::Create,
-	nullptr,
+	&android_mixer_plugin,
 };
